@@ -24,6 +24,8 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-cognito-apigateway-lambda`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.cognitoapigatewaylambda`|
 
+## Overview
+
 This AWS Solutions Construct implements an Amazon Cognito securing an Amazon API Gateway Lambda backed REST APIs pattern.
 
 Here is a minimal deployable pattern definition:
@@ -148,6 +150,8 @@ resource.add_method('POST')
 construct.add_authorizers()
 ```
 
+Java
+
 ```java
 import software.constructs.Construct;
 
@@ -187,24 +191,24 @@ construct.addAuthorizers();
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.|
-|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|User provided props to override the default props for the Lambda function.|
-|apiGatewayProps?|[`api.LambdaRestApiProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-apigateway.LambdaRestApi.html)|Optional user provided props to override the default props for API Gateway|
-|cognitoUserPoolProps?|[`cognito.UserPoolProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cognito.UserPoolProps.html)|Optional user provided props to override the default props for Cognito User Pool|
-|cognitoUserPoolClientProps?|[`cognito.UserPoolClientProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cognito.UserPoolClientProps.html)|Optional user provided props to override the default props for Cognito User Pool Client|
-|logGroupProps?|[`logs.LogGroupProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroupProps.html)|User provided props to override the default props for for the CloudWatchLogs LogGroup.|
+|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.Function.html)|Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.|
+|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.FunctionProps.html)|User provided props to override the default props for the Lambda function.|
+|apiGatewayProps?|[`api.LambdaRestApiProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_apigateway.LambdaRestApi.html)|Optional user provided props to override the default props for API Gateway|
+|cognitoUserPoolProps?|[`cognito.UserPoolProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_cognito.UserPoolProps.html)|Optional user provided props to override the default props for Cognito User Pool|
+|cognitoUserPoolClientProps?|[`cognito.UserPoolClientProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_cognito.UserPoolClientProps.html)|Optional user provided props to override the default props for Cognito User Pool Client|
+|logGroupProps?|[`logs.LogGroupProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_logs.LogGroupProps.html)|User provided props to override the default props for for the CloudWatchLogs LogGroup.|
 
 ## Pattern Properties
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|userPool|[`cognito.UserPool`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cognito.UserPool.html)|Returns an instance of cognito.UserPool created by the construct|
-|userPoolClient|[`cognito.UserPoolClient`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cognito.UserPoolClient.html)|Returns an instance of cognito.UserPoolClient created by the construct|
-|apiGateway|[`api.RestApi`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-apigateway.RestApi.html)|Returns an instance of api.RestApi created by the construct|
-|apiGatewayCloudWatchRole?|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.Role.html)|Returns an instance of the iam.Role created by the construct for API Gateway for CloudWatch access.|
-|apiGatewayLogGroup|[`logs.LogGroup`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroup.html)|Returns an instance of the LogGroup created by the construct for API Gateway access logging to CloudWatch.|
-|apiGatewayAuthorizer|[`api.CfnAuthorizer`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-apigateway.CfnAuthorizer.html)|Returns an instance of the api.CfnAuthorizer created by the construct for API Gateway methods authorization.|
-|lambdaFunction|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Returns an instance of lambda.Function created by the construct|
+|userPool|[`cognito.UserPool`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_cognito.UserPool.html)|Returns an instance of cognito.UserPool created by the construct|
+|userPoolClient|[`cognito.UserPoolClient`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_cognito.UserPoolClient.html)|Returns an instance of cognito.UserPoolClient created by the construct|
+|apiGateway|[`api.RestApi`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_apigateway.RestApi.html)|Returns an instance of api.RestApi created by the construct|
+|apiGatewayCloudWatchRole?|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_iam.Role.html)|Returns an instance of the iam.Role created by the construct for API Gateway for CloudWatch access.|
+|apiGatewayLogGroup|[`logs.LogGroup`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_logs.LogGroup.html)|Returns an instance of the LogGroup created by the construct for API Gateway access logging to CloudWatch.|
+|apiGatewayAuthorizer|[`api.CfnAuthorizer`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_apigateway.CfnAuthorizer.html)|Returns an instance of the api.CfnAuthorizer created by the construct for API Gateway methods authorization.|
+|lambdaFunction|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.Function.html)|Returns an instance of lambda.Function created by the construct|
 
 ## Default settings
 
@@ -239,7 +243,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -251,6 +255,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_apigateway
@@ -258,25 +264,25 @@ import aws_cdk.aws_cognito
 import aws_cdk.aws_iam
 import aws_cdk.aws_lambda
 import aws_cdk.aws_logs
-import aws_cdk.core
+import constructs
 
 
 class CognitoToApiGatewayToLambda(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-cognito-apigateway-lambda.CognitoToApiGatewayToLambda",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         api_gateway_props: typing.Any = None,
         cognito_user_pool_client_props: typing.Any = None,
-        cognito_user_pool_props: typing.Optional[aws_cdk.aws_cognito.UserPoolProps] = None,
+        cognito_user_pool_props: typing.Optional[typing.Union[aws_cdk.aws_cognito.UserPoolProps, typing.Dict[str, typing.Any]]] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -292,6 +298,10 @@ class CognitoToApiGatewayToLambda(
         :since: 0.8.0
         :summary: Constructs a new instance of the CognitoToApiGatewayToLambda class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CognitoToApiGatewayToLambda.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CognitoToApiGatewayToLambdaProps(
             api_gateway_props=api_gateway_props,
             cognito_user_pool_client_props=cognito_user_pool_client_props,
@@ -307,37 +317,37 @@ class CognitoToApiGatewayToLambda(
     def add_authorizers(self) -> None:
         return typing.cast(None, jsii.invoke(self, "addAuthorizers", []))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="apiGateway")
     def api_gateway(self) -> aws_cdk.aws_apigateway.RestApi:
         return typing.cast(aws_cdk.aws_apigateway.RestApi, jsii.get(self, "apiGateway"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="apiGatewayAuthorizer")
     def api_gateway_authorizer(self) -> aws_cdk.aws_apigateway.CfnAuthorizer:
         return typing.cast(aws_cdk.aws_apigateway.CfnAuthorizer, jsii.get(self, "apiGatewayAuthorizer"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="apiGatewayLogGroup")
     def api_gateway_log_group(self) -> aws_cdk.aws_logs.LogGroup:
         return typing.cast(aws_cdk.aws_logs.LogGroup, jsii.get(self, "apiGatewayLogGroup"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="userPool")
     def user_pool(self) -> aws_cdk.aws_cognito.UserPool:
         return typing.cast(aws_cdk.aws_cognito.UserPool, jsii.get(self, "userPool"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="userPoolClient")
     def user_pool_client(self) -> aws_cdk.aws_cognito.UserPoolClient:
         return typing.cast(aws_cdk.aws_cognito.UserPoolClient, jsii.get(self, "userPoolClient"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="apiGatewayCloudWatchRole")
     def api_gateway_cloud_watch_role(self) -> typing.Optional[aws_cdk.aws_iam.Role]:
         return typing.cast(typing.Optional[aws_cdk.aws_iam.Role], jsii.get(self, "apiGatewayCloudWatchRole"))
@@ -361,10 +371,10 @@ class CognitoToApiGatewayToLambdaProps:
         *,
         api_gateway_props: typing.Any = None,
         cognito_user_pool_client_props: typing.Any = None,
-        cognito_user_pool_props: typing.Optional[aws_cdk.aws_cognito.UserPoolProps] = None,
+        cognito_user_pool_props: typing.Optional[typing.Union[aws_cdk.aws_cognito.UserPoolProps, typing.Dict[str, typing.Any]]] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param api_gateway_props: Optional user provided props to override the default props for the API Gateway. Default: - Default props are used
@@ -382,6 +392,14 @@ class CognitoToApiGatewayToLambdaProps:
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(log_group_props, dict):
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(CognitoToApiGatewayToLambdaProps.__init__)
+            check_type(argname="argument api_gateway_props", value=api_gateway_props, expected_type=type_hints["api_gateway_props"])
+            check_type(argname="argument cognito_user_pool_client_props", value=cognito_user_pool_client_props, expected_type=type_hints["cognito_user_pool_client_props"])
+            check_type(argname="argument cognito_user_pool_props", value=cognito_user_pool_props, expected_type=type_hints["cognito_user_pool_props"])
+            check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
+            check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
+            check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
         self._values: typing.Dict[str, typing.Any] = {}
         if api_gateway_props is not None:
             self._values["api_gateway_props"] = api_gateway_props
